diff --git a/README.md b/README.md
index d3441f8..682c231 100644
--- a/README.md
+++ b/README.md
@@ -1,19 +1,19 @@
-# SimAntics
+# SimAI
-SimAntics is a port of FreeSO's reimplementation to .NET Standard.
+SimAI is a port of FreeSO's reimplementation to .NET Standard.
## Build Status
-| Service | Status |
-| ------- | -------------------------------------------------------------------------------------------------------------------------------------------------------- |
-| Github | [](https://github.com/simtactics/SimAntics/actions) |
+| Service | Status |
+| ------- | ------------------------------------------------------------------------------------------------------------------------------------------------ |
+| Github | [](https://github.com/simtactics/SimAI/actions) |
## Authors
- **Anthony Foxclaw** - _Maintainer_ - [tonytins](https://github.com/tonytins)
- **Rhys Simpson** - _Original work_ - [riperiperi](https://github.com/riperiperi)
-See also the list of [contributors](https://github.com/simtactics/SimAntics/contributors) who participated in this project.
+See also the list of [contributors](https://github.com/simtactics/SimAI/contributors) who participated in this project.
## License
diff --git a/src/SimAntics.Tests/SimAntics.Tests.csproj b/src/SimAI.Tests/SimAI.Tests.csproj
similarity index 88%
rename from src/SimAntics.Tests/SimAntics.Tests.csproj
rename to src/SimAI.Tests/SimAI.Tests.csproj
index 42c1782..7311189 100644
--- a/src/SimAntics.Tests/SimAntics.Tests.csproj
+++ b/src/SimAI.Tests/SimAI.Tests.csproj
@@ -4,6 +4,8 @@
netcoreapp3.1
false
+
+ SimAntics.Tests
@@ -18,7 +20,7 @@
-
+
diff --git a/src/SimAntics.Tests/UnitTest1.cs b/src/SimAI.Tests/UnitTest1.cs
similarity index 92%
rename from src/SimAntics.Tests/UnitTest1.cs
rename to src/SimAI.Tests/UnitTest1.cs
index d321034..504b666 100644
--- a/src/SimAntics.Tests/UnitTest1.cs
+++ b/src/SimAI.Tests/UnitTest1.cs
@@ -2,7 +2,7 @@ using System;
using System.Diagnostics;
using Xunit;
-namespace SimAntics.Tests
+namespace SimAI.Tests
{
public class UnitTest1
{
diff --git a/src/SimAntics.Tests/VMTest.cs b/src/SimAI.Tests/VMTest.cs
similarity index 91%
rename from src/SimAntics.Tests/VMTest.cs
rename to src/SimAI.Tests/VMTest.cs
index 70d9e34..ce304ca 100644
--- a/src/SimAntics.Tests/VMTest.cs
+++ b/src/SimAI.Tests/VMTest.cs
@@ -1,7 +1,7 @@
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
-namespace SimAntics.Tests
+namespace SimAI.Tests
{
public class VMTest
{
diff --git a/src/SimAntics.sln b/src/SimAI.sln
similarity index 82%
rename from src/SimAntics.sln
rename to src/SimAI.sln
index 4d1056d..61f1e58 100644
--- a/src/SimAntics.sln
+++ b/src/SimAI.sln
@@ -1,9 +1,9 @@
Microsoft Visual Studio Solution File, Format Version 12.00
# Visual Studio 15
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "SimAntics", "SimAntics\SimAntics.csproj", "{6B758449-9D5A-456A-A733-31B7841E538A}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "SimAI", "SimAI\SimAI.csproj", "{6B758449-9D5A-456A-A733-31B7841E538A}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "SimAntics.Tests", "SimAntics.Tests\SimAntics.Tests.csproj", "{4B7461A4-982A-4D89-92E3-E4D4A3EC85FB}"
+Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "SimAI.Tests", "SimAI.Tests\SimAI.Tests.csproj", "{4B7461A4-982A-4D89-92E3-E4D4A3EC85FB}"
EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
diff --git a/src/SimAntics/Direction.cs b/src/SimAI/Direction.cs
similarity index 95%
rename from src/SimAntics/Direction.cs
rename to src/SimAI/Direction.cs
index baf296f..4a459c8 100644
--- a/src/SimAntics/Direction.cs
+++ b/src/SimAI/Direction.cs
@@ -2,7 +2,7 @@
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
-namespace SimAntics
+namespace SimAI
{
public enum Direction
{
diff --git a/src/SimAntics/Engine/VMMemory.cs b/src/SimAI/Engine/VMMemory.cs
similarity index 91%
rename from src/SimAntics/Engine/VMMemory.cs
rename to src/SimAI/Engine/VMMemory.cs
index 48079e1..3d4b85c 100644
--- a/src/SimAntics/Engine/VMMemory.cs
+++ b/src/SimAI/Engine/VMMemory.cs
@@ -1,7 +1,7 @@
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
-namespace SimAntics.Engine
+namespace SimAI.Engine
{
public class VMMemory
{
diff --git a/src/SimAntics/Engine/VMScheduler.cs b/src/SimAI/Engine/VMScheduler.cs
similarity index 93%
rename from src/SimAntics/Engine/VMScheduler.cs
rename to src/SimAI/Engine/VMScheduler.cs
index 492fffa..87f489a 100644
--- a/src/SimAntics/Engine/VMScheduler.cs
+++ b/src/SimAI/Engine/VMScheduler.cs
@@ -2,9 +2,9 @@
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
using System.Collections.Generic;
-using SimAntics.Engine.Entities;
+using SimAI.Engine.Entities;
-namespace SimAntics.Engine
+namespace SimAI.Engine
{
public class VMScheduler
{
diff --git a/src/SimAntics/Engine/VMStackFrame.cs b/src/SimAI/Engine/VMStackFrame.cs
similarity index 98%
rename from src/SimAntics/Engine/VMStackFrame.cs
rename to src/SimAI/Engine/VMStackFrame.cs
index 17c0847..fd5a424 100644
--- a/src/SimAntics/Engine/VMStackFrame.cs
+++ b/src/SimAI/Engine/VMStackFrame.cs
@@ -1,10 +1,11 @@
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
-using SimAntics.Engine.Entities;
-using SimAntics.Marshals;
-namespace SimAntics.Engine
+using SimAI.Engine.Entities;
+using SimAI.Marshals;
+
+namespace SimAI.Engine
{
///
/// Holds information about the execution of a routine
diff --git a/src/SimAntics/Entities/VMEntity.cs b/src/SimAI/Entities/VMEntity.cs
similarity index 99%
rename from src/SimAntics/Entities/VMEntity.cs
rename to src/SimAI/Entities/VMEntity.cs
index 8b54d6d..0856b81 100644
--- a/src/SimAntics/Entities/VMEntity.cs
+++ b/src/SimAI/Entities/VMEntity.cs
@@ -3,7 +3,7 @@
// http://mozilla.org/MPL/2.0/.
using System.Collections.Generic;
-namespace SimAntics.Engine.Entities
+namespace SimAI.Engine.Entities
{
public class VMEntityRTTI
{
diff --git a/src/SimAntics/IVM.cs b/src/SimAI/IVM.cs
similarity index 94%
rename from src/SimAntics/IVM.cs
rename to src/SimAI/IVM.cs
index cfee025..8589488 100644
--- a/src/SimAntics/IVM.cs
+++ b/src/SimAI/IVM.cs
@@ -2,7 +2,7 @@
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
-namespace SimAntics
+namespace SimAI
{
public interface IVM
{
diff --git a/src/SimAntics/Interfaces/VMIMotiveDecay.cs b/src/SimAI/Interfaces/VMIMotiveDecay.cs
similarity index 91%
rename from src/SimAntics/Interfaces/VMIMotiveDecay.cs
rename to src/SimAI/Interfaces/VMIMotiveDecay.cs
index 591b828..bef333a 100644
--- a/src/SimAntics/Interfaces/VMIMotiveDecay.cs
+++ b/src/SimAI/Interfaces/VMIMotiveDecay.cs
@@ -1,7 +1,7 @@
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
-namespace SimAntics.Interfaces
+namespace SimAI.Interfaces
{
public interface VMIMotiveDecay : VMSerializable
{
diff --git a/src/SimAntics/Interfaces/VMSerializable.cs b/src/SimAI/Interfaces/VMSerializable.cs
similarity index 89%
rename from src/SimAntics/Interfaces/VMSerializable.cs
rename to src/SimAI/Interfaces/VMSerializable.cs
index 084352d..9c19dea 100644
--- a/src/SimAntics/Interfaces/VMSerializable.cs
+++ b/src/SimAI/Interfaces/VMSerializable.cs
@@ -1,7 +1,7 @@
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
-namespace SimAntics.Interfaces
+namespace SimAI.Interfaces
{
public interface VMSerializable
{
diff --git a/src/SimAntics/Marshals/VMMarshal.cs b/src/SimAI/Marshals/VMMarshal.cs
similarity index 91%
rename from src/SimAntics/Marshals/VMMarshal.cs
rename to src/SimAI/Marshals/VMMarshal.cs
index 948fbd3..af9ce13 100644
--- a/src/SimAntics/Marshals/VMMarshal.cs
+++ b/src/SimAI/Marshals/VMMarshal.cs
@@ -2,7 +2,7 @@
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
using System;
-namespace SimAntics.Marshals
+namespace SimAI.Marshals
{
public class VMMarshal
{
diff --git a/src/SimAntics/Marshals/VMStackFrameMarshal.cs b/src/SimAI/Marshals/VMStackFrameMarshal.cs
similarity index 98%
rename from src/SimAntics/Marshals/VMStackFrameMarshal.cs
rename to src/SimAI/Marshals/VMStackFrameMarshal.cs
index f27dd29..4ce62c7 100644
--- a/src/SimAntics/Marshals/VMStackFrameMarshal.cs
+++ b/src/SimAI/Marshals/VMStackFrameMarshal.cs
@@ -4,7 +4,7 @@
using System;
using System.IO;
-namespace SimAntics.Marshals
+namespace SimAI.Marshals
{
public class VMStackFrameMarshal
{
diff --git a/src/SimAntics/SimAntics.csproj b/src/SimAI/SimAI.csproj
similarity index 85%
rename from src/SimAntics/SimAntics.csproj
rename to src/SimAI/SimAI.csproj
index 0bdb0a6..c7b2018 100644
--- a/src/SimAntics/SimAntics.csproj
+++ b/src/SimAI/SimAI.csproj
@@ -2,6 +2,7 @@
netstandard2.0
+ SimAntics
diff --git a/src/SimAntics/VM.cs b/src/SimAI/VM.cs
similarity index 98%
rename from src/SimAntics/VM.cs
rename to src/SimAI/VM.cs
index bf2d741..b4fd88e 100644
--- a/src/SimAntics/VM.cs
+++ b/src/SimAI/VM.cs
@@ -3,10 +3,10 @@
// http://mozilla.org/MPL/2.0/.
using System;
using System.Collections.Generic;
-using SimAntics.Engine;
-using SimAntics.Engine.Entities;
+using SimAI.Engine;
+using SimAI.Engine.Entities;
-namespace SimAntics
+namespace SimAI
{
///
/// VM is an abstract class that contains the
diff --git a/src/SimAntics/VMClock.cs b/src/SimAI/VMClock.cs
similarity index 98%
rename from src/SimAntics/VMClock.cs
rename to src/SimAI/VMClock.cs
index 850b197..ab4bddf 100644
--- a/src/SimAntics/VMClock.cs
+++ b/src/SimAI/VMClock.cs
@@ -3,7 +3,7 @@
// http://mozilla.org/MPL/2.0/.
using System;
-namespace SimAntics
+namespace SimAI
{
public class VMClock
{
diff --git a/src/SimAntics/VMContext.cs b/src/SimAI/VMContext.cs
similarity index 94%
rename from src/SimAntics/VMContext.cs
rename to src/SimAI/VMContext.cs
index 92232a6..6ce9333 100644
--- a/src/SimAntics/VMContext.cs
+++ b/src/SimAI/VMContext.cs
@@ -1,7 +1,7 @@
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at
// http://mozilla.org/MPL/2.0/.
-namespace SimAntics
+namespace SimAI
{
public class VMContext
{
diff --git a/src/SimAntics/VMSimanticsException.cs b/src/SimAI/VMSimanticsException.cs
similarity index 98%
rename from src/SimAntics/VMSimanticsException.cs
rename to src/SimAI/VMSimanticsException.cs
index abb78fb..ab1ea0b 100644
--- a/src/SimAntics/VMSimanticsException.cs
+++ b/src/SimAI/VMSimanticsException.cs
@@ -4,9 +4,9 @@
using System;
using System.Collections.Generic;
using System.Text;
-using SimAntics.Engine;
+using SimAI.Engine;
-namespace SimAntics
+namespace SimAI
{
public class VMSimanticsException : Exception
{
diff --git a/src/SimAntics/Engine/VMThread.cs b/src/SimAI/Engine/VMThread.cs
similarity index 92%
rename from src/SimAntics/Engine/VMThread.cs
rename to src/SimAI/Engine/VMThread.cs
index 876d9d7..0f4e24b 100644
--- a/src/SimAntics/Engine/VMThread.cs
+++ b/src/SimAI/Engine/VMThread.cs
@@ -6,9 +6,9 @@
#endif
using System.Collections.Generic;
-using SimAntics.Engine.Entities;
+using SimAI.Engine.Entities;
-namespace SimAntics.Engine
+namespace SimAI.Engine
{
///
/// Compatibility class
@@ -44,7 +44,7 @@ namespace SimAntics.Engine
// Don't need to be serialized.
public int DialogCooldown = 0;
// the number of ticks that have executed so far this frame. If this exceeds the allowed max,
// the thread resets, and a SimAntics Error pops up.
public int TicksThisFrame = 0;
// the maximum number of primitives a thread can execute in one frame. Tweak appropriately.
@@ -44,7 +44,7 @@ namespace SimAntics.Engine
public int DialogCooldown = 0;
// the number of ticks that have executed so far this frame. If this exceeds the allowed max,
- // the thread resets, and a SimAntics Error pops up.
+ // the thread resets, and a SimAI Error pops up.
public int TicksThisFrame = 0;
// the maximum number of primitives a thread can execute in one frame. Tweak appropriately.